@@ -20,7 +20,11 @@ from MAST.submit import script_commands
 from pymatgen.core.structure import Structure
 from pymatgen.io.vaspio import Poscar
 from pymatgen.io.cifio import CifParser
-from custodian.custodian import ErrorHandler, backup
+from custodian.custodian import ErrorHandler
+try:
+   from custodian.custodian import backup
+except:
+   from custodian.utils import backup
 import logging
 
 class VaspReachedNSWErrorHandler(ErrorHandler):
@@ -111,4 +115,3 @@ class VaspReachedNSWErrorHandler(ErrorHandler):
 
     @property
     def to_dict(self): return {"@module": self.__class__.__module__, "@class": self.__class__.__name__, "output_filename": self.output_filename, "timeout": self.timeout}
-
